==> portal-contribuinte-3.160.0.zip: BOOT-INF/classes/sql/simam/validacaoarquivo/attMonetariaCreditoValidacao.sql <==
with contagemattmonetariacredito as (select nratualizacao, nranoatualizacao, count(1) as qtdregistrosattmonecredito from tceatualizamonecred group by nratualizacao, nranoatualizacao),
     contagemnratualizacao as (select nratualizacao, nranoatualizacao, nrcredito, nranocredito, cdcontroleleiato, idtipoatualizacaocredito, dtatualizacao, count(1) as nrAtualizacaoCredito from tceatualizamonecred group by nratualizacao, nranoatualizacao, nrcredito, nranocredito, cdcontroleleiato, idtipoatualizacaocredito, dtatualizacao)
select
    amc.idtceatualizamonecred,
    amc.nratualizacao,
    amc.nranoatualizacao,
    lc.nrcredito,
    lc.nranocredito,
    amc.idtipocredito,
    amc.idtipoatualizacaocredito,
    amc.dtatualizacao,
    amc.vlatualizacao,
    amc.dtatualizacao,
    camc.qtdregistrosattmonecredito,
    t.codigo as escopolei,
    c.nrAtualizacaoCredito,
    coalesce(lag(amc.nrcredito, 1) over (order by idtceatualizamonecred), 0) as nratualizacaoanterior
from tceatualizamonecred amc
         join contagemattmonetariacredito camc on amc.nratualizacao = camc.nratualizacao and amc.nranoatualizacao = camc.nranoatualizacao
         left join contagemnratualizacao c on c.nratualizacao = amc.nratualizacao and c.nranoatualizacao = amc.nranoatualizacao and c.nrcredito = amc.nrcredito and c.nranocredito = amc.nranocredito and c.dtatualizacao = amc.dtatualizacao and c.idtipoatualizacaocredito = amc.idtipoatualizacaocredito and c.cdcontroleleiato = amc.cdcontroleleiato
         left join tcelanccredito lc on lc.nrcredito = amc.nrcredito and lc.nranocredito = amc.nranocredito
         left  join cgato cg on cg.entidade = :entidade and cg.idato = amc.cdControleLeiAto
         left join tipoescopolei t on cg.idtipoescopolei = t.id
where amc.dtatualizacao between :dataInicial and :dataFinal

==> portal-contribuinte-3.326.0.zip: BOOT-INF/classes/sql/simam/validacaoarquivo/attMonetariaCreditoValidacao.sql <==
with contagemattmonetariacredito as (select nratualizacao, nranoatualizacao, count(1) as qtdregistrosattmonecredito from tceatualizamonecred group by nratualizacao, nranoatualizacao),
     contagemnratualizacao as (select nratualizacao, nranoatualizacao, nrcredito, nranocredito, cdcontroleleiato, idtipoatualizacaocredito, dtatualizacao, count(1) as nrAtualizacaoCredito from tceatualizamonecred group by nratualizacao, nranoatualizacao, nrcredito, nranocredito, cdcontroleleiato, idtipoatualizacaocredito, dtatualizacao)
select
    amc.idtceatualizamonecred,
    amc.nratualizacao,
    amc.nranoatualizacao,
    lc.nrcredito,
    lc.nranocredito,
    amc.idtipocredito,
    amc.idtipoatualizacaocredito,
    amc.dtatualizacao,
    amc.vlatualizacao,
    amc.dtatualizacao,
    camc.qtdregistrosattmonecredito,
    t.codigo as escopolei,
    coalesce(c.nrAtualizacaoCredito, 1) as nrAtualizacaoCredito,
    coalesce(lag(amc.nratualizacao, 1) over (order by idtceatualizamonecred), 0) as nratualizacaoanterior
from tceatualizamonecred amc
         join contagemattmonetariacredito camc on amc.nratualizacao = camc.nratualizacao and amc.nranoatualizacao = camc.nranoatualizacao
         left join contagemnratualizacao c on c.nratualizacao = amc.nratualizacao and c.nranoatualizacao = amc.nranoatualizacao and c.nrcredito = amc.nrcredito and c.nranocredito = amc.nranocredito and c.dtatualizacao = amc.dtatualizacao and c.idtipoatualizacaocredito = amc.idtipoatualizacaocredito and c.cdcontroleleiato = amc.cdcontroleleiato
         left join tcelanccredito lc on lc.nrcredito = amc.nrcredito and lc.nranocredito = amc.nranocredito
         left  join cgato cg on cg.entidade = :entidade and cg.idato = amc.cdControleLeiAto
         left join tipoescopolei t on cg.idtipoescopolei = t.id
where amc.dtatualizacao between :dataInicial and :dataFinal
